Crate walletkit_sqlite

Crate walletkit_sqlite 

Low-level SQLCipher (sqlite3mc) wrapper for WalletKit.

Safe Rust types over the SQLite C FFI. Raw symbols are resolved at compile time:

  • Native (not(wasm32)): linked against the sqlite3mc static library compiled from the downloaded amalgamation by build.rs.
  • WASM (wasm32): delegated to sqlite-wasm-rs (with the sqlite3mc feature) which ships its own WASM-compiled sqlite3mc.

The internal ffi module is the only file in this crate that contains unsafe code or C types.

Re-exports

pub use error::DbResult;
pub use error::Error;

Modules

cipher
sqlite3mc encryption configuration.
error
Error types for the safe SQLite wrapper.
test_utils
Shared test helpers for crates built on walletkit-sqlite.

Macros

params
Convenience macro for building parameter lists.

Structs

Connection
A SQLite database connection.
Row
A guard that represents the current row for a statement.
Statement
A prepared SQLite statement.
Transaction
An open database transaction.

Enums

StepResult
Result of a single sqlite3_step call.
Value
A value that can be bound to a prepared statement parameter or read from a result column.