Low-level SQLCipher (sqlite3mc) wrapper for WalletKit.
Safe Rust types over the SQLite C FFI. Raw symbols are resolved at
compile time:
- Native (
not(wasm32)): linked against thesqlite3mcstatic library compiled from the downloaded amalgamation bybuild.rs. - WASM (
wasm32): delegated tosqlite-wasm-rs(with thesqlite3mcfeature) which ships its ownWASM-compiledsqlite3mc.
The internal ffi module is the only file in this crate that contains
unsafe code or C types.
Re-exports
Modules
- cipher
sqlite3mcencryption configuration.- error
- Error types for the safe
SQLitewrapper. - test_
utils - Shared test helpers for crates built on
walletkit-sqlite.
Macros
- params
- Convenience macro for building parameter lists.
Structs
- Connection
- A
SQLitedatabase connection. - Row
- A guard that represents the current row for a statement.
- Statement
- A prepared
SQLitestatement. - Transaction
- An open database transaction.
Enums
- Step
Result - Result of a single
sqlite3_stepcall. - Value
- A value that can be bound to a prepared statement parameter or read from a result column.